import os
import requests
from dsrag_sdk.main import get_base_url, make_api_call
import PyPDF2
import docx2txt
import uuid

def extract_text_from_pdf(file_path):
    with open(file_path, 'rb') as file:
        # Create a PDF reader object
        pdf_reader = PyPDF2.PdfReader(file)

        # Initialize an empty string to store the extracted text
        extracted_text = ""

        # Loop through all the pages in the PDF file
        for page_num in range(len(pdf_reader.pages)):
            # Extract the text from the current page
            page_text = pdf_reader.pages[page_num].extract_text()

            # Add the extracted text to the final text
            extracted_text += page_text

    return extracted_text

def extract_text_from_docx(file_path):
    return docx2txt.process(file_path)


def create_document_via_text(knowledge_base_id: str, content: str, title: str = None, description: str = None, supp_id: str = None, auto_context_config: dict = None, document_type: str = "text", doc_id: str = "", file_name: str = "") -> dict:
    """
    Create a document in a knowledge base with raw text. For example, if you are adding Tweets to a knowledge base, you can just pass the text of the Tweet to this method.
    
    Args:
        knowledge_base_id (str): The ID of the knowledge base.
        content (str): The content of the document.
        title (str, optional): The title of the document. Defaults to None.
        link_to_source (str, optional): A link to the source of the document. Defaults to None.
        description (str, optional): The description of the document. Defaults to None.
        supp_id (str, optional): The ID of the document in your system. Defaults to None.
        chunk_header (str, optional): This is used to prepend context to every chunk created from this document.  Must be <= 500 characters. Defaults to None.
        auto_context (bool, optional): Whether to automatically prepend document-level context to every chunk. Cannot be True when `chunk_header` is set. ``NOTE:`` Setting this to `True` will incur an extra charge. Please see our pricing for more details. Defaults to None.
    
    Returns:
        dict: The document object.

    References:
        ``POST /knowledge_bases/{knowledge_base_id}/documents/raw_text``
    """
    if doc_id == "":
        doc_id = str(uuid.uuid4())
    data = {
        'text': content,
        "document_type": document_type,
        "id": doc_id,
        "file_name": file_name
    }
    if title:
        data['title'] = title
    if description:
        data['description'] = description
    if supp_id:
        data['supp_id'] = supp_id
    if auto_context_config is not None:
        data['auto_context_config'] = auto_context_config
    
    args = {
        'method': 'POST',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents/raw_text',
        'json': data,
    }
    return make_api_call(args)


def create_document_via_file(knowledge_base_id: str, file_path: str, title: str = None, description: str = None, supp_id: str = None, auto_context_config: dict = None) -> dict:

    # Get the file name from the file path
    file_name = os.path.basename(file_path)
    print ("File name: ", file_name)
    doc_id = str(uuid.uuid4())

    resp = requests.post(f"{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents/request_signed_file_url", json={"doc_id": doc_id})

    print ("url", resp.json()['url'])
    with open(file_path, 'rb') as file:
        response = requests.put(url=resp.json()['url'], data=file)
        print ("Response: ", response)
        print (response.status_code)
        if response.status_code != 200:
            return response
    
    audio_file_types = ['.mp3', '.wav', '.m4a', '.mp4']
    text_file_types = [".txt", ".md", ".csv"]

    # Read the file content now
    if file_name.endswith('.pdf'):
        content = extract_text_from_pdf(file_path)
    elif file_name.endswith('.docx'):
        content = extract_text_from_docx(file_path)
    elif file_name.endswith(tuple(audio_file_types)):
        data = {
            "document_type": "file",
            "id": doc_id,
            "file_name": file_name
        }
        if title:
            data['title'] = title
        if description:
            data['description'] = description
        if supp_id:
            data['supp_id'] = supp_id
        if auto_context_config is not None:
            data['auto_context_config'] = auto_context_config
        requests.post(f"{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents/{doc_id}/transcribe_audio", json=data)
        formatted_response = {
            "id": doc_id,
            "supp_id": supp_id,
            "knowledge_base_id": knowledge_base_id,
            "description": description,
            "file_name": file_name,
            "title": title,
            "document_type": "file",
            "vectorization_status": "CHUNKING_AND_EMBEDDING_STARTED",
        }
        return formatted_response
    elif file_name.endswith(tuple(text_file_types)):
        with open(file_path, 'rb') as f:
            content = f.read()
    else:
        return {"error": "Unsupported file type"}

    # If the file was uploaded successfully, create the document
    response = create_document_via_text(
        knowledge_base_id=knowledge_base_id,
        content=content,
        title=title,
        description=description,
        supp_id=supp_id,
        auto_context_config=auto_context_config,
        document_type="file",
        doc_id=doc_id,
        file_name=file_name
    )

    if response.get('id'):
        formatted_response = {
            "id": doc_id,
            "supp_id": supp_id,
            "knowledge_base_id": knowledge_base_id,
            "description": description,
            "file_name": file_name,
            "title": title,
            "document_type": "file",
            "vectorization_status": "CHUNKING_AND_EMBEDDING_STARTED",
        }

        return formatted_response

    return response


def list_documents(knowledge_base_id: str, title_begins_with: str = None, link_to_source: str = None, supp_id: str = None, vectorization_status: str = None) -> list:
    """
    List the documents in a knowledge base.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.
        title_begins_with (str, optional): A title prefix filter. Defaults to None.
        link_to_source (str, optional): Filter documents by their URL. Defaults to None.
        supp_id (str, optional): Filter documents by ``supp_id``. Defaults to None.

    Returns:
        list: A list of document objects.

    References:
        ``GET /knowledge_bases/{knowledge_base_id}/documents``
    """
    params = {}
    if title_begins_with:
        params['title_begins_with'] = title_begins_with
    if supp_id:
        params['supp_id'] = supp_id
    if vectorization_status:
        params['status'] = vectorization_status
    if link_to_source:
        params['link_to_source'] = link_to_source

    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents',
        'params': params,
    }
    resp = make_api_call(args)
    #documents = resp.get('documents', [])
    """while resp.get('next_page_token'):
        args['params']['next_page_token'] = resp['next_page_token']
        resp = superpowered.make_api_call(args)
        documents.extend(resp.get('documents', []))"""

    return resp


def get_document(knowledge_base_id: str, document_id: str, include_content: bool = False) -> dict:
    """
    Get an individual document from a knowledge base.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.
        document_id (str): The ID of the document.
        include_content (bool, optional): Whether to include the document content in the response. If you don't plan on displaying the content, setting this parameter to ``False`` could improve latency for large documents. Defaults to True.

    Returns:
        dict: A document object.

    References:
        ``GET /knowledge_bases/{knowledge_base_id}/documents/{document_id}``
    """
    params = {
        'include_content': include_content,
    }
    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents/{document_id}',
        'params': params,
    }
    return make_api_call(args)

def delete_document(knowledge_base_id: str, document_id: str) -> bool:
    """
    Delete a document from a knowledge base.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.
        document_id (str): The ID of the document.

    Returns:
        bool: Whether the document was successfully deleted.

    References:
        DELETE /knowledge_bases/{knowledge_base_id}/documents/{document_id}
    """

    args = {
        'method': 'DELETE',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}/documents/{document_id}',
    }

    
    return make_api_call(args)



from datetime import datetime
from typing import Optional
from typing_extensions import TypedDict

from dsrag_sdk.main import get_base_url, make_api_call


class UserInput(TypedDict):
    content: str
    timestamp: datetime

class ModelResponse(TypedDict):
    content: str
    timestamp: datetime

class SearchQuery(TypedDict):
    query: str
    kb_id: str

class RankedResult(TypedDict):
    content: str
    metadata: dict

class ChatThreadInteraction(TypedDict):
    user_input: UserInput
    model_response: ModelResponse
    search_queries: list[SearchQuery]
    ranked_results: list[RankedResult]


def create_chat_thread(knowledge_base_ids: list[str] = None, supp_id: str = None, model: str = None, temperature: float = None, system_message: str = None, title: str = None, response_length: str = None, auto_query_guidance: str = None) -> dict:
    """
    Create a chat thread. Chat threads are used to store the state of a conversation.

    Args:
        knowledge_base_ids (list[str], optional): A list of knowledge base IDs to use for the thread. Defaults to None.
        supp_id (str, optional): A supp ID to use for the thread. This will also be used for the ``supp_id`` field in the associated chat request billable events. Defaults to None.
        model (str, optional): The model to use for the thread. Defaults to None.
        temperature (float, optional): The temperature to use for the thread. Defaults to None.
        system_message (str, optional): The system message to use for the thread. Defaults to None.
        auto_query_guidance (str, optional): When we automatically generate queries based on user input, you may want to provide some additional guidance and/or context to the system. Defaults to ''.
        title (str, optional): The title to use for the thread. Defaults to None.
        response_length (str, optional): This parameter determines how long the response is. Defaults to 'medium'. Must be one of 'short', 'medium', or 'long'.

    Note:
        All parameters besides ``supp_id`` are the thread's default options. These options can be overridden when using the ``get_chat_response()`` function.

    Returns:
        dict: A chat thread object.

    References:
        ``POST /chat/threads``
    """
    data = {}

    if supp_id:
        data['supp_id'] = supp_id
    if title:
        data['title'] = title
    if knowledge_base_ids:
        data['kb_ids'] = knowledge_base_ids
    if model:
        data['model'] = model
    if temperature:
        data['temperature'] = temperature
    if system_message:
        data['system_message'] = system_message
    if response_length:
        data['target_output_length'] = response_length
    if auto_query_guidance:
        data['auto_query_guidance'] = auto_query_guidance

    args = {
        'method': 'POST',
        'url': f'{get_base_url()}/chat/threads',
        'json': data,
    }
    return make_api_call(args)


def list_chat_threads(supp_id: str = None):
    """
    List chat threads.

    Args:
        supp_id (str, optional): The supp_id of the thread. Defaults to None.

    Returns:
        dict: A list of chat thread objects.
    
    References:
        ``GET /chat/threads``
    """
    params = {}
    if supp_id:
        params['supp_id'] = supp_id

    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/chat/threads',
        'params': params,
    }
    threads = make_api_call(args)

    return threads


def get_chat_thread(thread_id: str) -> dict:
    """
    Get a chat thread.

    Args:
        thread_id (str): The ID of the thread.

    Returns:
        dict: A chat thread object.

    References:
        ``GET /chat/threads/{thread_id}``
    """
    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/chat/threads/{thread_id}',
    }
    return make_api_call(args)


def update_chat_thread(thread_id: str, knowledge_base_ids: list[str] = None, supp_id: str = None, model: str = None, temperature: float = None, system_message: str = None, title: str = None, response_length: str = None, auto_query_guidance: str = None) -> dict:
    """
    Update a chat thread.

    Args:
        thread_id (str): The ID of the thread.
        knowledge_base_ids (list[str], optional): A list of knowledge base IDs to use for the thread. Defaults to None.
        supp_id (str, optional): A supp ID to use for the thread. This will also be used for the ``supp_id`` field in the associated chat request billable events. Defaults to None.
        model (str, optional): The model to use for the thread. Defaults to None.
        temperature (float, optional): The temperature to use for the thread. Defaults to None.
        system_message (str, optional): The system message to use for the thread. Defaults to None.
        auto_query_guidance (str, optional): When we automatically generate queries based on user input, you may want to provide some additional guidance and/or context to the system. Defaults to None.
        title (str, optional): The title to use for the thread. Defaults to None.
        use_rse (bool, optional): Whether or not to use Relevant Segment Extraction (RSE). Defaults to None.
        segment_length (str, optional): Ignored if `use_rse` is False. This parameter determines how long each result (segment) is. Defaults to None. Must be one of 'very_short', 'short', 'medium', or 'long'.
        response_length (str, optional): This parameter determines how long the response is. Must be one of 'short', 'medium', or 'long'.

    Returns:
        dict: A chat thread object.

    References:
        ``PATCH /chat/threads/{thread_id}``
    """
    data = {}

    if supp_id:
        data['supp_id'] = supp_id
    if title:
        data['title'] = title
    if knowledge_base_ids:
        data['kb_ids'] = knowledge_base_ids
    if model:
        data['model'] = model
    if temperature:
        data['temperature'] = temperature
    if system_message:
        data['system_message'] = system_message
    if response_length:
        data['target_output_length'] = response_length
    if auto_query_guidance:
        data['auto_query_guidance'] = auto_query_guidance

    args = {
        'method': 'PATCH',
        'url': f'{get_base_url()}/chat/threads/{thread_id}',
        'json': data,
    }
    return make_api_call(args)


def delete_chat_thread(thread_id: str) -> dict:
    """
    Delete a chat thread.

    Args:
        thread_id (str): The ID of the thread.

    Returns:
        dict: A chat thread object.

    References:
        ``DELETE /chat/threads/{thread_id}``
    """
    args = {
        'method': 'DELETE',
        'url': f'{get_base_url()}/chat/threads/{thread_id}',
    }
    return make_api_call(args)


def format_chat_interaction(interaction: dict) -> ChatThreadInteraction:

    ranked_results = []
    for segment in interaction["relevant_segments"]:
        ranked_results.append({
            "content": segment['text'],
            "metadata": {
                "document_id": segment['doc_id'],
                "knowledge_base_id": segment['kb_id'],
                "num_chunks": segment['chunk_end'] - segment['chunk_start'] + 1,
                "result_type": "segment",
                "file_name": segment['file_name'],
                "file_type": segment['document_type'],
            },
        })
    formatted_response = ChatThreadInteraction(
        user_input=interaction.get('user_input', {}),
        model_response=interaction.get('model_response', {}),
        search_queries=interaction.get('search_queries', []),
        ranked_results=ranked_results
    )

    return formatted_response

def get_chat_response(thread_id: str, input: str, knowledge_base_ids: list = None, model: str = None, temperature: float = None, system_message: str = None, response_length: str = None, timeout: int = 90, auto_query_guidance: str = None) -> dict:
    """
    Get a response for a specific chat thread. This endpoint uses a tool we call "Auto Query" to reformulate queries to the knowledge base given the recent chat history as well as user input.

    Note:
        To ensure "Auto Query" works as well as it can, please ensure the knowledge bases you are using have good titles and descriptions. If you are only querying from a single knowledge base, this doesn't matter.

    Args:
        thread_id (str): The ID of the thread.
        input (str): The user's input.
        knowledge_base_ids (list, optional): A list of knowledge base IDs to use for the thread. **These override any default config options defined in the thread itself**. Defaults to None.
        model (str, optional): The model to use for the thread. **This overrides any default config options defined in the thread itself**. Defaults to None.
        temperature (float, optional): The temperature to use for the thread. **This overrides any default config options defined in the thread itself**. Defaults to None.
        system_message (str, optional): The system message to use for the thread. **This overrides any default config options defined in the thread itself**. Defaults to None.
        auto_query_guidance (str, optional): When we automatically generate queries based on user input, you may want to provide some additional guidance and/or context to the system. **This overrides any default config options defined in the thread itself**. Defaults to None.
        response_length (str, optional): This parameter determines how long the response is. Must be one of 'short', 'medium', or 'long'. **This overrides any default config options defined in the thread itself**. Defaults to None.
        
    Returns:
        dict: A chat response object.

    References:
        ``POST /chat/threads/{thread_id}/get_response``
    """
    data = {
        #'async': True,
        'user_input': input,
    }
    if knowledge_base_ids:
        data['knowledge_base_ids'] = knowledge_base_ids
    if model:
        data['model'] = model
    if temperature:
        data['temperature'] = temperature
    if system_message:
        data['system_message'] = system_message
    if auto_query_guidance:
        data['auto_query_guidance'] = auto_query_guidance
    if response_length:
        data['response_length'] = response_length

    args = {
        'method': 'POST',
        'url': f'{get_base_url()}/chat/threads/{thread_id}/get_response',
        'json': data,
    }
    resp = make_api_call(args)
    # Format the response
    formatted_response = format_chat_interaction(resp)

    return formatted_response
    

def list_thread_interactions(thread_id: str, order: str = None) -> dict:
    """
    List interactions for a chat thread.

    Args:
        thread_id (str): The ID of the thread.
        order (str, optional): The order to return the interactions in. Must be `asc` or `desc`. Defaults to `desc`.

    Returns:
        dict: A list of chat interaction objects.

    References:
        ``GET /chat/threads/{thread_id}/interactions``
    """
    params = {}
    if order:
        if order.lower() not in ['asc', 'desc']:
            raise ValueError('`order` parameter must be "asc" or "desc"')
        params['order'] = order.lower()

    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/chat/threads/{thread_id}/interactions',
        'params': params,
    }
    resp = make_api_call(args)

    all_interactions = []
    for interaction in resp:
        all_interactions.append(format_chat_interaction(interaction))

    return all_interactions


from dsrag_sdk.main import (
    set_base_url,
)

from dsrag_sdk.knowledge_bases import (
    create_knowledge_base,
    update_knowledge_base,
    list_knowledge_bases,
    get_knowledge_base,
    delete_knowledge_base,
)

from dsrag_sdk.documents import (
    create_document_via_text,
    create_document_via_file,
    list_documents,
    get_document,
    delete_document,
)

from dsrag_sdk.chat import (
    create_chat_thread,
    list_chat_threads,
    get_chat_thread,
    update_chat_thread,
    delete_chat_thread,
    list_thread_interactions,
    get_chat_response
)


__all__ = [
    'set_base_url',
    'create_knowledge_base',
    'update_knowledge_base',
    'list_knowledge_bases',
    'get_knowledge_base',
    'delete_knowledge_base',
    'create_document_via_text',
    'create_document_via_file',
    'list_documents',
    'get_document',
    'delete_document',
    'create_chat_thread',
    'list_chat_threads',
    'get_chat_thread',
    'update_chat_thread',
    'delete_chat_thread',
    'list_thread_interactions',
    'get_chat_response'
]




class DuplicateKnowledgeBaseError(Exception):
    pass


class DuplicateDocumentContentError(Exception):
    pass


class DocumentLengthError(Exception):
    pass


class AuthenticationFailedError(Exception):
    pass


class InternalServerError(Exception):
    pass


class InvalidRequestError(Exception):
    pass


class TimeoutError(Exception):
    pass


class NotFoundError(Exception):
    pass


class RateLimitError(Exception):
    pass


import os
import json
import requests

"""from .exceptions import (
    AuthenticationFailedError,
    DuplicateDocumentContentError,
    DuplicateKnowledgeBaseError,
    DocumentLengthError,
    InternalServerError,
    InvalidRequestError,
    NotFoundError,
)"""


_BASE_URL = "http://0.0.0.0:8000"

def set_base_url(url: str):
    global _BASE_URL
    _BASE_URL = url

def get_base_url():
    return _BASE_URL


################## ERROR HANDLING ##################
"""def read_errors():
    module_path = os.path.abspath(__file__)
    module_dir = os.path.dirname(module_path)
    errors_path = os.path.join(module_dir, 'errors.json')
    
    with open(errors_path) as file:
        errors_data = json.load(file)
    
    return errors_data


ERRORS = {e['code']: e for e in read_errors()}"""


def make_api_call(args: dict) -> dict:
    """exception_classes = {
        "AuthenticationFailedError": AuthenticationFailedError,
        "DuplicateDocumentContentError": DuplicateDocumentContentError,
        "DocumentLengthError": DocumentLengthError,
        "InternalServerError": InternalServerError,
        "InvalidRequestError": InvalidRequestError,
        "NotFoundError": NotFoundError,
        "TimeoutError": TimeoutError,
        "DuplicateKnowledgeBaseError": DuplicateKnowledgeBaseError
    }"""

    resp = requests.request(**args)
    headers = resp.headers
    if resp.ok and args['method'] == 'DELETE':
        return True
    elif not resp.ok and args['method'] == 'DELETE':
        resp_json = {}
    else:
        resp_json = resp.json()
    if headers.get('error_code'):
        # error_code = int(headers['error_code'])
        raise Exception(resp_json, resp.status_code)
        """if error_code in ERRORS:
            try:
                _exp = exception_classes[ERRORS[error_code]['python_sdk_exception']]
                raise _exp(resp_json, resp.status_code)
            except KeyError:
                raise Exception(resp_json, resp.status_code)
        else:
            raise Exception(resp_json, resp.status_code)"""
    elif not resp.ok:
        raise Exception(resp_json, resp.status_code)
    else:
        return resp_json


from dsrag_sdk.main import get_base_url, make_api_call

def create_knowledge_base(title: str, description: str = None, supp_id: str = None, language_code: str = "en") -> dict:
    """
    Create a knowledge base.

    Args:
        title (str): The title of the knowledge base.
        description (str, optional): The description of the knowledge base. Defaults to None.
        supp_id (str, optional): A supplemental ID for the knowledge base for internal use. Defaults to None.
        language_code (str, optional): The language code of the knowledge base. Defaults to 'en'.

    Returns:
        dict: The knowledge base object.

    Note:
        The ``title`` and ``description`` fields are important for "Auto Query", which is used to automatically generate search queries for particular knowledge bases based on the user's input.

    References:
        ``POST /knowledge_bases``
    """
    data = {
        'title': title,
    }
    if description:
        data['description'] = description
    if supp_id:
        data['supp_id'] = supp_id
    if language_code:
        data['language_code'] = language_code
    args = {
        'method': 'POST',
        'url': f'{get_base_url()}/knowledge_bases',
        'json': data,
    }
    return make_api_call(args)


def get_knowledge_base(knowledge_base_id: str) -> dict:
    """
    Get an individual knowledge base by it's ID.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.

    Returns:
        dict: The knowledge base object.
    
    References:
       ``GET /knowledge_bases/{knowledge_base_id}``
    """
    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}',
    }
    return make_api_call(args)


def update_knowledge_base(knowledge_base_id: str, title: str = None, description: str = None, supp_id: str = None, language_code: str = None) -> dict:
    """
    Update a knowledge base object.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.
        title (str, optional): The title of the knowledge base. Defaults to None.
        description (str, optional): The description of the knowledge base. Defaults to None.
        supp_id (str, optional): The ID of the knowledge base in your system. Defaults to None.
        language_code (str, optional): The language code of the knowledge base. Defaults to None.

    Returns:
        dict: The knowledge base object.

    References:
        ``PATCH /knowledge_bases/{knowledge_base_id}``
    """
    data = {}
    if title:
        data['title'] = title
    if description:
        data['description'] = description
    if supp_id:
        data['supp_id'] = supp_id
    if language_code:
        data['language_code'] = language_code
    args = {
        'method': 'PATCH',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}',
        'json': data,
    }
    return make_api_call(args)


def list_knowledge_bases(supp_id: str = None) -> list:
    """
    List all knowledge bases.

    Args:
        title (str, optional): The title of the knowledge base. Defaults to None.
        supp_id (str, optional): The ID of the knowledge base in your system. Defaults to None.

    Returns:
        list: A list of knowledge base objects that match the filter criteria.

    Note:
        You can use ``title`` as a prefix to filter your search. For example, if you have a knowledge base titled "FAQ", you can use ``title="F"`` to find it.

    References:
        ``GET /knowledge_bases``
    """
    params = {}
    """if title:
        params['title_begins_with'] = title"""
    if supp_id:
        params['supp_id'] = supp_id

    args = {
        'method': 'GET',
        'url': f'{get_base_url()}/knowledge_bases',
        'params': params,
    }
    knowledge_bases = make_api_call(args)

    """while resp.get('next_page_token'):
        args['params']['next_page_token'] = resp['next_page_token']
        resp = dsrag.make_api_call(args)
        knowledge_bases.extend(resp.get('knowledge_bases', []))"""

    return knowledge_bases

def delete_knowledge_base(knowledge_base_id: str) -> bool:
    """
    Delete a knowledge base by it's ID.

    Args:
        knowledge_base_id (str): The ID of the knowledge base.

    Returns:
        bool: True if the knowledge base was deleted successfully, False otherwise.

    References:
        ``DELETE /knowledge_bases/{knowledge_base_id}``
    """
    args = {
        'method': 'DELETE',
        'url': f'{get_base_url()}/knowledge_bases/{knowledge_base_id}',
    }
    return make_api_call(args)